#[repr(u8)]pub enum CodecType {
SpeexNarrowband = 0,
SpeexWideband = 1,
SpeexUltrawideband = 2,
CeltMono = 3,
OpusVoice = 4,
OpusMusic = 5,
}Variants
SpeexNarrowband = 0
Mono, 16 bit, 8 kHz, bitrate dependent on the quality setting
SpeexWideband = 1
Mono, 16 bit, 16 kHz, bitrate dependent on the quality setting
SpeexUltrawideband = 2
Mono, 16 bit, 32 kHz, bitrate dependent on the quality setting
CeltMono = 3
Mono, 16 bit, 48 kHz, bitrate dependent on the quality setting
OpusVoice = 4
Mono, 16 bit, 48 kHz, bitrate dependent on the quality setting, optimized for voice
OpusMusic = 5
Stereo, 16 bit, 48 kHz, bitrate dependent on the quality setting, optimized for music