InPacket

Struct InPacket 

pub struct InPacket<'a> { /* private fields */ }

Implementations

Source

impl<'a> InPacket<'a>

pub fn try_new(direction: Direction, data: &'a [u8]) -> Result<Self, Error>

Do some sanity checks before creating the object.

pub fn new(direction: Direction, data: &'a [u8]) -> Self

This method expects that data holds a valid packet.

If not, further function calls may panic.

pub fn header(&self) -> &InHeader<'a>

pub fn content(&self) -> &[u8]

pub fn ack_packet(&self) -> Result<Option<u16>, Error>

Get the acknowledged packet id if this is an ack packet.

pub fn into_audio(self) -> Result<InAudio<'a>, Error>

Parse this packet into a voice packet.

pub fn into_command(self) -> Result<InCommand<'a>, Error>

Put this packet into a command packet.

pub fn into_s2cinit(self) -> Result<InS2CInit<'a>, Error>

pub fn into_c2sinit(self) -> Result<InC2SInit<'a>, Error>